@@ -4,7 +4,7 @@
  * See http://mod-qos.sourceforge.net/ for further
  * details.
  *
- * Copyright (C) 2023 Pascal Buchbinder
+ * Copyright (C) 2024 Pascal Buchbinder
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -29,8 +29,8 @@
 /* ----------------------------------
  * version info
  * ---------------------------------- */
-static const char man_version[] = "11.73";
-static const char man_date[] = "January 2023";
+static const char man_version[] = "11.75";
+static const char man_date[] = "April 2024";
 
 /* ----------------------------------
  * definitions
