@@ -5,7 +5,7 @@
  *
  * See http://mod-qos.sourceforge.net/ for further details.
  *
- * Copyright (C) 2023 Pascal Buchbinder
+ * Copyright (C) 2024 Pascal Buchbinder
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -306,14 +306,14 @@ int main(int argc, const char * const argv[]) {
 
   qs_setuid(username, cmd);
 
-  preg = apr_palloc(pool, sizeof *preg);
+  preg = apr_palloc(pool, sizeof(qs_regex_t));
   if(qs_regcomp(preg, pattern, PCRE2_DOTALL) != 0) {
     fprintf(stderr, "ERROR, could not compile '%s'\n", pattern);
     exit(1);
   }
   apr_pool_pre_cleanup_register(pool, preg, qs_pregfree);
   if(clearpattern) {
-    clearpreg = apr_palloc(pool, sizeof *clearpreg);
+    clearpreg = apr_palloc(pool, sizeof(qs_regex_t));
     if(qs_regcomp(clearpreg, clearpattern, PCRE2_DOTALL) != 0) {
       fprintf(stderr, "ERROR, could not compile '%s'\n", clearpattern);
       exit(1);
