@@ -7,7 +7,7 @@
  * See http://mod-qos.sourceforge.net/ for further
  * details.
  *
- * Copyright (C) 2023 Pascal Buchbinder
+ * Copyright (C) 2024 Pascal Buchbinder
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -138,7 +138,7 @@ int STACK_qs_cmp(const char * const *_pA, const char * const *_pB) {
 
 /* compiles a pcre (exit on error) */
 static qs_regex_t *qos_pcre_compile(apr_pool_t *pool, char *pattern, int option) {
-  qs_regex_t *preg = apr_palloc(pool, sizeof *preg);
+  qs_regex_t *preg = apr_palloc(pool, sizeof(qs_regex_t));
   if(qs_regcomp(preg, pattern, PCRE2_DOTALL|option) != 0) {
     fprintf(stderr, "ERROR, rule <%s> could not compile pcre\n", pattern);
     exit(1);
