@@ -9,7 +9,7 @@
  * See http://mod-qos.sourceforge.net/ for further
  * details.
  *
- * Copyright (C) 2023 Pascal Buchbinder
+ * Copyright (C) 2024 Pascal Buchbinder
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -992,7 +992,7 @@ static void qsInitCounter(apr_pool_t *pool, apr_table_t *counters) {
   const char *envFile = getenv(QSCOUNTERPATH);
   if(envFile != NULL) {
     qs_regmatch_t regm[QS_MAX_REG_MATCH];
-    qs_regex_t *pcrestat = apr_palloc(pool, sizeof *pcrestat);
+    qs_regex_t *pcrestat = apr_palloc(pool, sizeof(qs_regex_t));
     FILE *file = fopen(envFile, "r"); 
     if(qs_regcomp(pcrestat, COUNTER_PATTERN, PCRE2_CASELESS) != 0) {
       fprintf(stderr, "ERROR, could not compile '%s'\n", COUNTER_PATTERN);
