@@ -6,7 +6,7 @@
  * See http://mod-qos.sourceforge.net/ for further
  * details.
  *
- * Copyright (C) 2022 Pascal Buchbinder
+ * Copyright (C) 2024 Pascal Buchbinder
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
@@ -37,9 +37,6 @@ static const char revision[] = "$Id: qssign.c 2654 2022-05-13 09:12:42Z pbuchbin
 #include <openssl/evp.h>
 #include <openssl/hmac.h>
 
-/* PCRE */
-#include <pcre.h>
-
 /* apr/apr-util */
 #define QS_USEAPR 1
 #include <apr.h>
@@ -50,6 +47,9 @@ static const char revision[] = "$Id: qssign.c 2654 2022-05-13 09:12:42Z pbuchbin
 #include <apr_file_io.h>
 #include <apr_time.h>
 
+#define PCRE2_CODE_UNIT_WIDTH 8
+#include <pcre2.h>
+
 #include "qs_util.h"
 #include "qs_apo.h"
 
@@ -65,7 +65,7 @@ static void (*m_end)(const char *, int) = NULL;
 static int m_end_pos = 0;
 static const char *m_sec = NULL;
 static const EVP_MD *m_evp;
-static const pcre *m_filter = NULL;
+static qs_regex_t *m_filter = NULL;
 
 typedef struct {
   const char* start_fmt;
@@ -433,7 +433,7 @@ static void qs_sign(const char *sec) {
       qs_set_format(line);
       m_end(m_sec, 1);
     }
-    if(pcre_exec(m_filter, NULL, line, line_size, 0, 0, NULL, 0) >= 0) {
+    if(m_filter != NULL && qs_regexec_len(m_filter, line, line_len, 0, NULL, 0) >= 0) {
       printf("%s\n", line);
       fflush(stdout);
     } else {
@@ -761,14 +761,12 @@ int main(int argc, const char * const argv[]) {
   }
 
   if(filter != NULL) {
-    const char *errptr = NULL;
-    int erroffset;
-    m_filter = pcre_compile(filter, 0, &errptr, &erroffset, NULL);
-    if(m_filter == NULL) {
-      fprintf(stderr, "failed to compile filter pattern <%s> at position %d,"
-            " reason: %s\n", filter, erroffset, errptr);
+    m_filter = apr_palloc(pool, sizeof(qs_regex_t));
+    if(qs_regcomp(m_filter, filter, 0) != 0) {
+      fprintf(stderr, "failed to compile filter pattern <%s>\n", filter);
       exit(1);
     }
+    apr_pool_pre_cleanup_register(pool, m_filter, qs_pregfree);
   }
 
   if(m_evp == NULL) {
